/**
 * apeman bud for README file.
 * @memberof module:apeman-bud-readme/lib
 * @function setup
 * @param {object} params - Template params.
 * @param {string} params.sections - Section file path.
 * @param {object} params.pkg - Package data.
 * @param {string} params.repo - GitHub Repository name. (eg. 'ape-repo/ap-tmpl')
 * @param {object} params.badges - Badge data.
 * @param {boolean} [params.badges.travis=false] - Should show travis badge.
 * @param {boolean} [params.badges.codeclimate=false] - Should show codeclimate badge.
 * @param {boolean} [params.badges.codeclimateCoverage=false] - Should show codeclimate coverage badge.
 * @param {boolean} [params.badges.gemnasium=false] - Should show gemnasium badge.
 * @param {boolean} [params.badges.npm=false] - Should show npm badge.
 * @param {boolean} [params.badges.bower=false] - Should show bower badge.
 * @param {object} params.links - Link urls.
 * @param {string} params.overview - Overview file path.
 * @param {object} params.vars - Custom variables.
 * @returns {object} - Coz bud configuration.
 */

'use strict'

const expandglob = require('expandglob')
const path = require('path')
const pkg = require('../package.json')
const assert = require('assert')
const moment = require('moment')
const fs = require('fs')

/** @lends setup */
function setup (params = {}) {
  assert.ok(params.pkg, `[${pkg.name}] params.pkg is required.`)
  assert.ok(params.sections, `[${pkg.name}] params.sections is required.`)
  assert.ok(params.repo, `[${pkg.name}] params.repo is required.`)
  return {
    force: true,
    mode: '444',
    path: 'README.md',
    tmpl: fs.readFileSync(__dirname + '/../asset/tmpl.hbs').toString(),
    data: {
      pkg: params.pkg,
      generator: 'coz',
      today: moment(new Date()).format('YYYY-MM-DD'),
      tmplPkg: require('../package.json'),
      sections: expandglob.sync(params.sections).map((filename) => {
        let name = path.relative(process.cwd(), filename)
        let anchor = name.replace(/[\/\¥]/g, '-')
        return {
          anchor: path.basename(anchor, path.extname(anchor)),
          name: name,
          filename: filename
        }
      }),
      badges: params.badges,
      repo: params.repo,
      links: params.links,
      overview: params.overview,
      vars: params.vars
    }
  }
}

module.exports = setup
