/**
 * Test case for setup.
 * Runs with nodeunit.
 */
'use strict'

const setup = require('../lib/setup.js')
const assert = require('assert')
const coz = require('coz')
const co = require('co')

describe('setup', () => {
  it('Setup', () => co(function * () {
    let buds = [ setup({
      pkg: {
        name: 'foo',
        description: 'This is foo desc.',
        license: 'MIT'
      },
      badges: {
        travis: true,
        travisCom: true,
        travisComToken: 'hoge',
        bower: true
      },
      links: {
        foo: 'http://foo/bar/baz'
      },
      repo: 'foo/bar',
      sections: __dirname + '/../doc/mockups/mock-*.md'
    })
    ]
    for (let bud of buds) {
      assert.ok(bud)
      assert.ok(bud.tmpl)
      bud.force = true
      bud.mkdirp = true
      bud.path = __dirname + '/../tmp/testing-readme/README.md'
      coz.render(bud)
    }
  }))

  it('Setup with missing props.', () => co(function * () {
    try {
      setup({})
    } catch (e) {
      assert.ok(e)
    }
  }))
})

/* global describe, before, after, it */
